@@ -1185,6 +1185,7 @@ sub run {
                         my ($dep, $pkg_name) = @{$d};
                         my $replacement = $OBSOLETE_PACKAGES->value($pkg_name)
                           // '';
+                        next if $proc->pkg_src eq 'lintian';
                         $replacement = ' => ' . $replacement
                           if $replacement ne '';
                         if (   $pkg_name eq $alternatives[0][0]
@@ -1345,6 +1346,8 @@ sub run {
                 tag 'vcs-browser-links-to-empty-view', $uri
                   if $uri =~ m%rev=0&sc=0%;
             } else {
+                tag 'vcs', $vcs;
+                tag 'vcs-uri', $uri;
                 $seen_vcs{$vcs}++;
                 foreach my $regex ($KNOWN_VCS_HOSTERS->all) {
                     foreach my $re_vcs (@{$KNOWN_VCS_HOSTERS->value($regex)}) {
