@@ -24,12 +24,14 @@ use warnings;
 use autodie;
 
 use Lintian::Data;
+use Lintian::Deb822Parser qw(
+  DCTRL_COMMENTS_AT_EOL
+  read_dpkg_control
+);
 use Lintian::Relation;
 use Lintian::Tags qw(tag);
 use Lintian::Util qw(
   file_is_encoded_in_non_utf8
-  DCTRL_COMMENTS_AT_EOL
-  read_dpkg_control
   strip
 );
 
@@ -51,8 +53,9 @@ my %KNOWN_SPECIAL_DEPENDS = map { $_ => 1 } qw(
 sub run {
     my ($pkg, $type, $info) = @_;
     my $testsuites = $info->field('testsuite', '');
-    my $control = $info->index('debian/tests/control');
-    my $control_autodep8 = $info->index('debian/tests/control.autodep8');
+    my $control = $info->index_resolved_path('debian/tests/control');
+    my $control_autodep8
+      = $info->index_resolved_path('debian/tests/control.autodep8');
     my $needs_control = 0;
 
     tag 'testsuite-autopkgtest-missing' if ($testsuites !~ /autopkgtest/);
@@ -199,7 +202,7 @@ sub check_test_file {
     my ($info, $directory, $name, $line) = @_;
     # Special case with "Tests-Directory: ." (see #849880)
     my $path = $directory eq '.' ? $name : "$directory/$name";
-    my $index = $info->index($path);
+    my $index = $info->index_resolved_path($path);
 
     if ($name !~ m{^ [ [:alnum:] \+ \- \. / ]++ $}xsm) {
         tag 'illegal-runtime-test-name', $name,
